==> vue-components-1.5.43.tgz: package/lib/modals/src/Modal.vue.rd.js <==
import { useInjectStyle as f } from "../../shared/hooks/useInjectStyle.rd.js";
import { defineComponent as C, openBlock as l, createBlock as s, unref as i, mergeProps as c, isRef as v, withCtx as h, createElementVNode as b, normalizeClass as t, createVNode as k, renderSlot as d, createCommentVNode as $ } from "vue";
import { useVModel as y } from "@vueuse/core";
import "../../node_modules/ant-design-vue/es/modal/index.rd.js";
/* empty css                                                          *//* empty css                                                              *//* empty css                                                               */import w from "./ModalFooter.vue.rd.js";
import g from "./ModalHeader.vue.rd.js";
import P from "./ModalPrimaryHeader.vue.rd.js";
import { modalProps as B } from "./props.rd.js";
import I from "../../node_modules/ant-design-vue/es/modal/style/index.css.rd.js";
import M from "./modal.scss.rd.js";
import "../../spinners/index.rd.js";
import T from "../../node_modules/ant-design-vue/es/modal/Modal.rd.js";
import V from "../../spinners/src/AbsoluteLoader.vue.rd.js";
const O = /* @__PURE__ */ C({
  __name: "Modal",
  props: B(),
  emits: ["update:visible", "cancel", "close", "accept"],
  setup(u, { emit: m }) {
    const r = u;
    f(I, "ant-modal"), f(M, "ant-modal-custom");
    const a = y(r, "visible");
    function p() {
      typeof r.beforeClose == "function" ? r.beforeClose() : (m("update:visible", !1), m("close"));
    }
    return (o, e) => (l(), s(i(T), c({
      visible: i(a),
      "onUpdate:visible": e[2] || (e[2] = (n) => v(a) ? a.value = n : null),
      keyboard: o.keyboard,
      bodyStyle: { padding: "0px", overflow: "hidden" },
      footer: null,
      title: null,
      closeIcon: !1,
      closable: !1,
      maskClosable: o.maskClosable
    }, o.$attrs), {
      default: h(() => [
        b("div", {
          class: t([[
            { "dark:border-1px dark:border-solid dark:border-slate-700": o.border },
            o.containerClass
          ], "z-10 overflow-hidden round-big bg-surface"])
        }, [
          k(i(V), {
            loading: o.loading,
            description: o.loadingDescription
          }, null, 8, ["loading", "description"]),
          o.$slots.header ? d(o.$slots, "header", { key: 0 }) : o.showHeader && o.primaryHeader ? (l(), s(P, {
            key: 1,
            hoverableClose: o.hoverableClose,
            title: o.headTitle,
            showCloseIcon: o.showCloseIcon,
            onClose: p
          }, null, 8, ["hoverableClose", "title", "showCloseIcon"])) : o.showHeader ? (l(), s(g, {
            key: 2,
            hoverableClose: o.hoverableClose,
            headTitle: o.headTitle,
            showCloseIcon: o.showCloseIcon,
            onClose: p
          }, null, 8, ["hoverableClose", "headTitle", "showCloseIcon"])) : $("", !0),
          b("div", {
            class: t(["p-7 text-muted", { "p-0": o.noPadding }])
          }, [
            d(o.$slots, "default")
          ], 2),
          !o.$slots.footer && o.showFooter ? (l(), s(w, {
            key: 3,
            class: t(o.footerClass),
            okBtnProps: o.okBtnProps,
            cancelBtnProps: o.cancelBtnProps,
            onAccept: e[0] || (e[0] = (n) => o.$emit("accept")),
            onCancel: e[1] || (e[1] = (n) => o.$emit("cancel"))
          }, null, 8, ["class", "okBtnProps", "cancelBtnProps"])) : d(o.$slots, "footer", { key: 4 })
        ], 2)
      ]),
      _: 3
    }, 16, ["visible", "keyboard", "maskClosable"]));
  }
});
export {
  O as default
};

==> vue-components-1.6.3.tgz: package/lib/modals/src/Modal.vue.rd.js <==
import { useInjectStyle as f } from "../../shared/hooks/useInjectStyle.rd.js";
import { defineComponent as C, openBlock as l, createBlock as s, unref as i, mergeProps as c, isRef as v, withCtx as h, createElementVNode as b, normalizeClass as t, createVNode as k, renderSlot as d, createCommentVNode as $ } from "vue";
import { useVModel as y } from "@vueuse/core";
import "../../node_modules/ant-design-vue/es/modal/index.rd.js";
/* empty css                                                          *//* empty css                                                              *//* empty css                                                               */import w from "./ModalFooter.vue.rd.js";
import g from "./ModalHeader.vue.rd.js";
import P from "./ModalPrimaryHeader.vue.rd.js";
import { modalProps as B } from "./props.rd.js";
import I from "../../node_modules/ant-design-vue/es/modal/style/index.css.rd.js";
import M from "./modal.scss.rd.js";
import "../../spinners/index.rd.js";
import T from "../../node_modules/ant-design-vue/es/modal/Modal.rd.js";
import V from "../../spinners/src/AbsoluteLoader.vue.rd.js";
const O = /* @__PURE__ */ C({
  __name: "Modal",
  props: B(),
  emits: ["update:visible", "cancel", "close", "accept"],
  setup(u, { emit: m }) {
    const r = u;
    f(I, "ant-modal"), f(M, "ant-modal-custom");
    const a = y(r, "visible");
    function p() {
      typeof r.beforeClose == "function" ? r.beforeClose() : (m("update:visible", !1), m("close"));
    }
    return (o, e) => (l(), s(i(T), c({
      visible: i(a),
      "onUpdate:visible": e[2] || (e[2] = (n) => v(a) ? a.value = n : null),
      keyboard: o.keyboard,
      bodyStyle: { padding: "0px", overflow: "hidden" },
      footer: null,
      title: null,
      closeIcon: !1,
      closable: !1,
      maskClosable: o.maskClosable
    }, o.$attrs), {
      default: h(() => [
        b("div", {
          class: t([[
            { "dark:border-1px dark:border-solid dark:border-slate-700": o.border },
            o.containerClass
          ], "z-10 overflow-hidden round-big bg-surface"])
        }, [
          k(i(V), {
            loading: o.loading,
            description: o.loadingDescription
          }, null, 8, ["loading", "description"]),
          o.$slots.header ? d(o.$slots, "header", { key: 0 }) : o.showHeader && o.primaryHeader ? (l(), s(P, {
            key: 1,
            hoverableClose: o.hoverableClose,
            title: o.headTitle,
            showCloseIcon: o.showCloseIcon,
            onClose: p
          }, null, 8, ["hoverableClose", "title", "showCloseIcon"])) : o.showHeader ? (l(), s(g, {
            key: 2,
            hoverableClose: o.hoverableClose,
            headTitle: o.headTitle,
            showCloseIcon: o.showCloseIcon,
            onClose: p
          }, null, 8, ["hoverableClose", "headTitle", "showCloseIcon"])) : $("", !0),
          b("div", {
            class: t(["p-7", { "p-0": o.noPadding }])
          }, [
            d(o.$slots, "default")
          ], 2),
          !o.$slots.footer && o.showFooter ? (l(), s(w, {
            key: 3,
            class: t(o.footerClass),
            okBtnProps: o.okBtnProps,
            cancelBtnProps: o.cancelBtnProps,
            onAccept: e[0] || (e[0] = (n) => o.$emit("accept")),
            onCancel: e[1] || (e[1] = (n) => o.$emit("cancel"))
          }, null, 8, ["class", "okBtnProps", "cancelBtnProps"])) : d(o.$slots, "footer", { key: 4 })
        ], 2)
      ]),
      _: 3
    }, 16, ["visible", "keyboard", "maskClosable"]));
  }
});
export {
  O as default
};
